from pathlib import Path

# TODO: XDG Base Directory Specification
ROOT_DIR_PATH = Path(__file__).parents[2]

CONFIG_DIR_PATH = ROOT_DIR_PATH / "config"
CONFIG_SESSION_FILENAME = "config_session.json"
CONFIG_SESSION_PATH = CONFIG_DIR_PATH / CONFIG_SESSION_FILENAME

OPTIONS_SESSION_FILENAME = "options_session.json"
OPTIONS_SESSION_PATH = CONFIG_DIR_PATH / OPTIONS_SESSION_FILENAME

ANIMAL_DB_FILENAME = "animal_db.json"
ANIMAL_DB_PATH = CONFIG_DIR_PATH / ANIMAL_DB_FILENAME

CROSS_MODAL_CONFIG_FILENAME = "config_cross_modal.json"
CROSS_MODAL_CONFIG_PATH = CONFIG_DIR_PATH / CROSS_MODAL_CONFIG_FILENAME

DATA_DIR_PATH = ROOT_DIR_PATH / "data"

LOG_PATH = ROOT_DIR_PATH / "log"

SAMBA_MOUNT_PATH = ROOT_DIR_PATH / "samba_mount"
SAMBA_BACKUP_DIR_NAME = "backup"
SAMBA_BACKUP_DIR_PATH = SAMBA_MOUNT_PATH / SAMBA_BACKUP_DIR_NAME

SERVICE_DIR_NAME = "services"
SERVICE_DIR_PATH = ROOT_DIR_PATH / SERVICE_DIR_NAME
MOUNT_SERVICE_NAME = "mount.service"
MOUNT_SERVICE_PATH = SERVICE_DIR_PATH / MOUNT_SERVICE_NAME
SYNC_SERVICE_NAME = "sync.service"
SYNC_SERVICE_PATH = SERVICE_DIR_PATH / SYNC_SERVICE_NAME

SESSION_COUNTER_PATH = CONFIG_DIR_PATH / "session_counter.json"

ASSETS_DIR_PATH = ROOT_DIR_PATH / "assets"
ASSET_CLICKER_PATH = ASSETS_DIR_PATH / "clicker.wav"
